package sgc.portal.cd.cd0201.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cd.cd0201.dto.CD02010001USearch;
import sgc.portal.cd.cd0201.model.CD02010001U;
import sgc.portal.cd.cd0201.model.ConDayWrk;
import sgc.portal.cd.cd0201.model.ConDayWrkCn;

import java.util.List;

@Mapper
public interface CD02010001UMapper {
	
	//CON_DAY_WRK 현장일보
	List<EasyHashMap<String, Object>> getListConDayWrkCalKo(CD02010001USearch search);
	
	List<EasyHashMap<String, Object>> getListConDayWrkCalEn(CD02010001USearch search);
		
	//CON_DAY_WRK 업무
	EasyHashMap<String, Object> getListConDayWrk(CD02010001USearch search);

    int insertConDayWrk(ConDayWrk conDayWrk);

    int updateConDayWrk(ConDayWrk conDayWrk);

    int deleteConDayWrk(ConDayWrk conDayWrk);
	 
    //draft
    int updateDraft(CD02010001U cD02010001U);
    
	//CON_DAY_WRK_CN 업무
	List<EasyHashMap<String, Object>> getListConDayWrkCn(CD02010001USearch search);
	
	int insertConDayWrkCn(ConDayWrkCn conDayWrkCn);

    int updateConDayWrkCn(ConDayWrkCn conDayWrkCn);
    
    int deleteConDayWrkCn(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkManAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkEqAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkEqprtAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkBdAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkBdprtAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkPrAll(ConDayWrkCn conDayWrkCn);
    int deleteConDayWrkPtAll(ConDayWrkCn conDayWrkCn);
	
	//CON_DAY_WRK_MANPWR 출역인원
	List<EasyHashMap<String, Object>> getListConDayWrkMan(CD02010001USearch search);
	
	int insertConDayWrkMan(CD02010001U cD02010001U);

    int updateConDayWrkMan(CD02010001U cD02010001U);

    int deleteConDayWrkMan(CD02010001U cD02010001U);
	
    //CON_DAY_WRK_EQPM 주요장비
	List<EasyHashMap<String, Object>> getListConDayWrkEq(CD02010001USearch search);
	
	int insertConDayWrkEq(CD02010001U cD02010001U);

    int updateConDayWrkEq(CD02010001U cD02010001U);

    int deleteConDayWrkEq(CD02010001U cD02010001U);
    
    //CON_DAY_WRK_EQPMPRT 주요장비출력
  	List<EasyHashMap<String, Object>> getListConDayWrkEqprt(CD02010001USearch search);
  	
  	int insertConDayWrkEqprt(CD02010001U cD02010001U);
  	
  	int updateConDayWrkEqprt(CD02010001U cD02010001U);

    int deleteConDayWrkEqprt(CD02010001U cD02010001U);
	
    //CON_DAY_WRK_BDMT 주요자재
	List<EasyHashMap<String, Object>> getListConDayWrkBd(CD02010001USearch search);
	
	int insertConDayWrkBd(CD02010001U cD02010001U);

    int updateConDayWrkBd(CD02010001U cD02010001U);

    int deleteConDayWrkBd(CD02010001U cD02010001U);
    
    //CON_DAY_WRK_BDMTPRT 주요자재출력
  	List<EasyHashMap<String, Object>> getListConDayWrkBdprt(CD02010001USearch search);
  	
  	int insertConDayWrkBdprt(CD02010001U cD02010001U);
  	
  	int updateConDayWrkBdprt(CD02010001U cD02010001U);

    int deleteConDayWrkBdprt(CD02010001U cD02010001U);
	
    //CON_DAY_WRK_PROG Progress
	List<EasyHashMap<String, Object>> getListConDayWrkPr(CD02010001USearch search);
	
	int insertConDayWrkPr(CD02010001U cD02010001U);

    int updateConDayWrkPr(CD02010001U cD02010001U);

    int deleteConDayWrkPr(CD02010001U cD02010001U);
	
    //CON_DAY_WRK_PHOTO 공정사진
	List<EasyHashMap<String, Object>> getListConDayWrkPt(CD02010001USearch search);
	
	int insertConDayWrkPt(CD02010001U cD02010001U);

    int updateConDayWrkPt(CD02010001U cD02010001U);

    int deleteConDayWrkPt(CD02010001U cD02010001U);
	
    //CON_DAY_MST_JOBTYP 공종마스터
  	List<EasyHashMap<String, Object>> getListConDayMstJobtypKo(CD02010001USearch search);
  	List<EasyHashMap<String, Object>> getListConDayMstJobtypEn(CD02010001USearch search);
  	
  	//CON_DAY_MST_EQPM 장비마스터
  	List<EasyHashMap<String, Object>> getListConDayMstEqpmKo(CD02010001USearch search);
  	List<EasyHashMap<String, Object>> getListConDayMstEqpmEn(CD02010001USearch search);
  	
  	//CON_DAY_MST_BDMT 자재마스터
  	List<EasyHashMap<String, Object>> getListConDayMstBdmtKo(CD02010001USearch search);
  	List<EasyHashMap<String, Object>> getListConDayMstBdmtEn(CD02010001USearch search);
  	
  	//CON_DAY_SITE_COVEND 공사일보)협력업체
  	List<EasyHashMap<String, Object>> getListConDaySiteCovend(CD02010001USearch search);
    
}
